OverriddenSimulationDB

Struct OverriddenSimulationDB 

pub struct OverriddenSimulationDB<'a, DB: DatabaseRef> {
    pub inner_db: &'a DB,
    pub overrides: &'a HashMap<Address, HashMap<U256, U256>>,
    pub native_balance_overrides: &'a HashMap<Address, U256>,
}
A wrapper over an actual SimulationDB that allows overriding specific storage slots and native balances

Fields

inner_db: &'a DB

Wrapped database. Will be queried if a requested item is not found in the overrides.

overrides: &'a HashMap<Address, HashMap<U256, U256>>

A mapping from account address to storage. Storage is a mapping from slot index to slot value.

native_balance_overrides: &'a HashMap<Address, U256>

A mapping from account address to its overridden native balance. An override for an account absent from the inner database materializes it as an empty account holding that balance.

Implementations

Source

impl<'a, DB: DatabaseRef> OverriddenSimulationDB<'a, DB>

pub fn new( inner_db: &'a DB, overrides: &'a HashMap<Address, HashMap<U256, U256>>, native_balance_overrides: &'a HashMap<Address, U256>, ) -> Self

Creates a new OverriddenSimulationDB.