pub struct BlockParam {
pub hash: Option<Bytes>,
pub chain: Option<Chain>,
pub number: Option<i64>,
}Fields
hash: Option<Bytes>chain: Option<Chain>👎Deprecated:
The chain field is deprecated and will be removed in a future version.
number: Option<i64>Trait Implementations
Sourceimpl Clone for BlockParam
impl Clone for BlockParam
Sourcefn clone(&self) -> BlockParam
fn clone(&self) -> BlockParam
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BlockParam
impl Debug for BlockParam
Sourceimpl DeepSizeOf for BlockParam
impl DeepSizeOf for BlockParam
Sourcefn deep_size_of_children(&self, context: &mut Context) -> usize
fn deep_size_of_children(&self, context: &mut Context) -> usize
Returns an estimation of the heap-managed storage of this object.
This does not include the size of the object itself. Read more
Sourcefn deep_size_of(&self) -> usize
fn deep_size_of(&self) -> usize
Returns an estimation of a total size of memory owned by the
object, including heap-managed storage. Read more
Sourceimpl<'de> Deserialize<'de> for BlockParam
impl<'de> Deserialize<'de> for BlockParam
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<BlockParam, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<BlockParam, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&Block> for BlockParam
impl From<&Block> for BlockParam
Sourcefn from(value: &Block) -> BlockParam
fn from(value: &Block) -> BlockParam
Converts to this type from the input type.
Sourceimpl Hash for BlockParam
impl Hash for BlockParam
Sourceimpl PartialEq for BlockParam
impl PartialEq for BlockParam
Sourceimpl Serialize for BlockParam
impl Serialize for BlockParam
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl<'__s> ToSchema<'__s> for BlockParam
impl<'__s> ToSchema<'__s> for BlockParam
impl Eq for BlockParam
impl StructuralPartialEq for BlockParam