pub struct ProtocolComponentsRequestBody {
pub protocol_system: String,
pub component_ids: Option<Vec<String>>,
pub tvl_gt: Option<f64>,
pub chain: Chain,
pub pagination: PaginationParams,
}Fields
protocol_system: StringFilters by protocol, required to correctly apply unconfirmed state from ReorgBuffers
component_ids: Option<Vec<String>>Filter by component ids
tvl_gt: Option<f64>The minimum TVL of the protocol components to return, denoted in the chain’s native token.
chain: Chainpagination: PaginationParamsMax page size supported is 500
Implementations
Sourceimpl ProtocolComponentsRequestBody
impl ProtocolComponentsRequestBody
pub fn system_filtered( system: &str, tvl_gt: Option<f64>, chain: Chain, ) -> ProtocolComponentsRequestBody
pub fn id_filtered( system: &str, ids: Vec<String>, chain: Chain, ) -> ProtocolComponentsRequestBody