pub struct ProtocolStateDelta {
pub component_id: String,
pub updated_attributes: HashMap<String, Bytes>,
pub deleted_attributes: HashSet<String>,
}Expand description
Represents a change in protocol state.
Fields
component_id: Stringupdated_attributes: HashMap<String, Bytes>deleted_attributes: HashSet<String>Implementations
Sourceimpl ProtocolStateDelta
impl ProtocolStateDelta
Sourcepub fn merge(&mut self, other: &ProtocolStateDelta)
pub fn merge(&mut self, other: &ProtocolStateDelta)
Merges ‘other’ into ‘self’.
During merge of these deltas a special situation can arise when an attribute is present in
self.deleted_attributes and `other.update_attributes``. If we would just merge the sets
of deleted attributes or vice versa, it would be ambiguous and potential lead to a
deletion of an attribute that should actually be present, or retention of an actually
deleted attribute.
This situation is handled the following way:
- If an attribute is deleted and in the next message recreated, it is removed from the
set of deleted attributes and kept in updated_attributes. This way it's temporary
deletion is never communicated to the final receiver.
- If an attribute was updated and is deleted in the next message, it is removed from
updated attributes and kept in deleted. This way the attributes temporary update (or
potentially short-lived existence) before its deletion is never communicated to the
final receiver.Trait Implementations
Sourceimpl Clone for ProtocolStateDelta
impl Clone for ProtocolStateDelta
Sourcefn clone(&self) -> ProtocolStateDelta
fn clone(&self) -> ProtocolStateDelta
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProtocolStateDelta
impl Debug for ProtocolStateDelta
Sourceimpl Default for ProtocolStateDelta
impl Default for ProtocolStateDelta
Sourcefn default() -> ProtocolStateDelta
fn default() -> ProtocolStateDelta
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ProtocolStateDelta
impl<'de> Deserialize<'de> for ProtocolStateDelta
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ProtocolStateDelta, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ProtocolStateDelta, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ProtocolComponentStateDelta> for ProtocolStateDelta
impl From<ProtocolComponentStateDelta> for ProtocolStateDelta
Sourcefn from(value: ProtocolComponentStateDelta) -> ProtocolStateDelta
fn from(value: ProtocolComponentStateDelta) -> ProtocolStateDelta
Converts to this type from the input type.
Sourceimpl PartialEq for ProtocolStateDelta
impl PartialEq for ProtocolStateDelta
Sourceimpl Serialize for ProtocolStateDelta
impl Serialize for ProtocolStateDelta
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl<'__s> ToSchema<'__s> for ProtocolStateDelta
impl<'__s> ToSchema<'__s> for ProtocolStateDelta
impl StructuralPartialEq for ProtocolStateDelta