pub struct ResponseAccount {
pub chain: Chain,
pub address: Bytes,
pub title: String,
pub slots: HashMap<Bytes, Bytes>,
pub native_balance: Bytes,
pub token_balances: HashMap<Bytes, Bytes>,
pub code: Bytes,
pub code_hash: Bytes,
pub balance_modify_tx: Bytes,
pub code_modify_tx: Bytes,
pub creation_tx: Option<Bytes>,
}Expand description
Account struct for the response from Tycho server for a contract state request.
Code is serialized as a hex string instead of a list of bytes.
Fields
chain: Chainaddress: BytesThe address of the account as hex encoded string
title: StringThe title of the account usualy specifying its function within the protocol
slots: HashMap<Bytes, Bytes>Contract storage map of hex encoded string values
native_balance: BytesThe balance of the account in the native token
token_balances: HashMap<Bytes, Bytes>Balances of this account in other tokens (only tokens balance that are relevant to the protocol are returned here)
code: BytesThe accounts code as hex encoded string
code_hash: BytesThe hash of above code
balance_modify_tx: BytesTransaction hash which last modified native balance
code_modify_tx: BytesTransaction hash which last modified code
creation_tx: Option<Bytes>The creation_tx field is deprecated.
Transaction hash which created the account
Implementations