pub struct ResponseProtocolState {
pub component_id: String,
pub attributes: HashMap<String, Bytes>,
pub balances: HashMap<Bytes, Bytes>,
}Expand description
Protocol State struct for the response from Tycho server for a protocol state request.
Fields
component_id: StringComponent id this state belongs to
attributes: HashMap<String, Bytes>Attributes of the component. If an attribute’s value is a bigint,
it will be encoded as a big endian signed hex string.
balances: HashMap<Bytes, Bytes>Sum aggregated balances of the component