pub struct ResponseToken {
pub chain: Chain,
pub address: Bytes,
pub symbol: String,
pub decimals: u32,
pub tax: u64,
pub gas: Vec<Option<u64>>,
pub quality: u32,
}Expand description
Token struct for the response from Tycho server for a tokens request.
Fields
chain: Chainaddress: BytesThe address of this token as hex encoded string
symbol: StringA shorthand symbol for this token (not unique)
decimals: u32The number of decimals used to represent token values
tax: u64The tax this token charges on transfers in basis points
gas: Vec<Option<u64>>Gas usage of the token, currently is always a single averaged value
quality: u32Quality is between 0-100, where:
- 100: Normal ERC-20 Token behavior
- 75: Rebasing token
- 50: Fee-on-transfer token
- 10: Token analysis failed at first detection
- 5: Token analysis failed multiple times (after creation)
- 0: Failed to extract attributes, like Decimal or Symbol