pub struct StateRequestParameters {
pub tvl_gt: Option<u64>,
pub inertia_min_gt: Option<u64>,
pub include_balances: bool,
pub pagination: PaginationParams,
}๐Deprecated:
Use StateRequestBody instead
Fields
tvl_gt: Option<u64>๐Deprecated:
Use StateRequestBody instead
The minimum TVL of the protocol components to return, denoted in the chainโs native token.
inertia_min_gt: Option<u64>๐Deprecated:
Use StateRequestBody instead
The minimum inertia of the protocol components to return.
include_balances: bool๐Deprecated:
Use StateRequestBody instead
Whether to include ERC20 balances in the response.
pagination: PaginationParams๐Deprecated:
Use StateRequestBody instead
Implementations
Sourceimpl StateRequestParameters
impl StateRequestParameters
pub fn new(include_balances: bool) -> StateRequestParameters
pub fn to_query_string(&self) -> String