VersionParam

Struct VersionParam 

pub struct VersionParam {
    pub timestamp: Option<NaiveDateTime>,
    pub block: Option<BlockParam>,
}
The version of the requested state, given as either a timestamp or a block.

If block is provided, the state at that exact block is returned. Will error if the block has not been processed yet. If timestamp is provided, the state at the latest block before that timestamp is returned. Defaults to the current time.

Fields

timestamp: Option<NaiveDateTime>block: Option<BlockParam>

Implementations