pub struct TxWithChanges {
pub tx: Transaction,
pub protocol_components: HashMap<String, ProtocolComponent>,
pub account_deltas: HashMap<Bytes, AccountDelta>,
pub state_updates: HashMap<String, ProtocolComponentStateDelta>,
pub balance_changes: HashMap<String, HashMap<Bytes, ComponentBalance>>,
pub account_balance_changes: HashMap<Bytes, HashMap<Bytes, AccountBalance>>,
pub entrypoints: HashMap<String, HashSet<EntryPoint>>,
pub entrypoint_params: HashMap<String, HashSet<(TracingParams, String)>>,
}Expand description
Changes grouped by their respective transaction.
Fields
tx: Transactionprotocol_components: HashMap<String, ProtocolComponent>account_deltas: HashMap<Bytes, AccountDelta>state_updates: HashMap<String, ProtocolComponentStateDelta>balance_changes: HashMap<String, HashMap<Bytes, ComponentBalance>>account_balance_changes: HashMap<Bytes, HashMap<Bytes, AccountBalance>>entrypoints: HashMap<String, HashSet<EntryPoint>>entrypoint_params: HashMap<String, HashSet<(TracingParams, String)>>Implementations
Sourceimpl TxWithChanges
impl TxWithChanges
pub fn new( tx: Transaction, protocol_components: HashMap<String, ProtocolComponent>, account_deltas: HashMap<Bytes, AccountDelta>, protocol_states: HashMap<String, ProtocolComponentStateDelta>, balance_changes: HashMap<String, HashMap<Bytes, ComponentBalance>>, account_balance_changes: HashMap<Bytes, HashMap<Bytes, AccountBalance>>, entrypoints: HashMap<String, HashSet<EntryPoint>>, entrypoint_params: HashMap<String, HashSet<(TracingParams, String)>>, ) -> TxWithChanges
Sourcepub fn merge(&mut self, other: TxWithChanges) -> Result<(), MergeError>
pub fn merge(&mut self, other: TxWithChanges) -> Result<(), MergeError>
Merges this update with another one.
The method combines two TxWithChanges instances if they are on the same block.
NB: It is expected that other is a more recent update than self is and the two are
combined accordingly.
Errors
Returns a MergeError if any of the above conditions are violated.