pub enum NativeAsset {
Wrapper {
native: Token,
wrapper: Token,
},
SharedBalance {
native: Token,
routable: Token,
},
NativeOnly {
native: Token,
},
}Expand description
The native asset representations and economic relationship for a chain.
Variants
Wrapper
Separate native and ERC-20 balances connected by a wrapper contract.
Separate token representations exposing the same underlying balance.
NativeOnly
A native balance without a routable token representation.
Implementations
Sourceimpl NativeAsset
impl NativeAsset
pub fn native_token(&self) -> &Token
pub fn routable_token(&self) -> Option<&Token>
Sourcepub fn wrapper(&self) -> Option<&Token>
pub fn wrapper(&self) -> Option<&Token>
Returns the routable token only when it is backed by a real wrapper contract.
Sourcepub fn representations(&self) -> impl Iterator<Item = &Token>
pub fn representations(&self) -> impl Iterator<Item = &Token>
Returns each token representation of this economic asset.