pub struct ProtocolComponentState {
pub component_id: String,
pub attributes: HashMap<String, Bytes>,
pub balances: HashMap<Bytes, Bytes>,
}Fields
component_id: Stringattributes: HashMap<String, Bytes>balances: HashMap<Bytes, Bytes>Implementations
Sourceimpl ProtocolComponentState
impl ProtocolComponentState
pub fn new( component_id: &str, attributes: HashMap<String, Bytes>, balances: HashMap<Bytes, Bytes>, ) -> ProtocolComponentState
Sourcepub fn apply_state_delta(
&mut self,
delta: &ProtocolComponentStateDelta,
) -> Result<(), MergeError>
pub fn apply_state_delta( &mut self, delta: &ProtocolComponentStateDelta, ) -> Result<(), MergeError>
Applies state deltas to this state.
This method assumes that the passed delta is “newer” than the current state.
Sourcepub fn apply_balance_delta(
&mut self,
delta: &HashMap<Bytes, ComponentBalance>,
) -> Result<(), MergeError>
pub fn apply_balance_delta( &mut self, delta: &HashMap<Bytes, ComponentBalance>, ) -> Result<(), MergeError>
Applies balance deltas to this state.
This method assumes that the passed delta is “newer” than the current state.