pub struct ProtocolComponentStateDelta {
pub component_id: String,
pub updated_attributes: HashMap<String, Bytes>,
pub deleted_attributes: HashSet<String>,
}Fields
component_id: Stringupdated_attributes: HashMap<String, Bytes>deleted_attributes: HashSet<String>Implementations
Sourceimpl ProtocolComponentStateDelta
impl ProtocolComponentStateDelta
pub fn new( component_id: &str, updated_attributes: HashMap<String, Bytes>, deleted_attributes: HashSet<String>, ) -> ProtocolComponentStateDelta
Sourcepub fn merge(
&mut self,
other: ProtocolComponentStateDelta,
) -> Result<(), MergeError>
pub fn merge( &mut self, other: ProtocolComponentStateDelta, ) -> Result<(), MergeError>
Merges this update with another one.
The method combines two ProtocolComponentStateDelta instances if they are for the same
protocol component.
NB: It is assumed that other is a more recent update than self is and the two are
combined accordingly.
Errors
This method will return CoreError::MergeError if any of the above
conditions is violated.