pub enum TokenQuality {
Good,
Bad {
reason: String,
},
}Expand description
Represents the quality of a token.
Good: Indicates that the token has successfully passed the analysis process.Bad: Indicates that the token has failed the analysis process. In this case, a detailed reason for the failure is provided.
Note: Transfer taxes do not impact the token’s quality.
Even if a token has transfer taxes, as long as it successfully passes the analysis,
it will still be marked as Good.
Variants
Implementations
Sourceimpl TokenQuality
impl TokenQuality