VersionKind

Enum VersionKind 

pub enum VersionKind {
    Last,
    First,
    Index(i64),
}
References certain states within a single block.

Note: Not all methods that take a version will support all version kinds, the versions here are included for completeness and to document the retrieval behaviour that is possible with the storage layout. Please refer to the individual implementation for information about which version kinds it supports.

Variants



Last

Represents the final state within a specific block. Essentially, it retrieves the state subsequent to the execution of the last transaction executed in that block.



First

Represents the initial state of a specific block. In other words, it is the state before any transaction has been executed within that block.



Index(i64)

Represents a specific transactions indexed position within a block. It includes the state after executing the transaction at that index.