pub enum BlockIdentifier {
Number((Chain, i64)),
Hash(Bytes),
Latest(Chain),
}Expand description
Identifies a block in storage.
Variants
Number((Chain, i64))
Identifies the block by its position on a specified chain.
This form of identification has potential risks as it may become ambiguous in certain situations. For example, if the block has not been finalised, there exists a possibility of forks occurring. As a result, the same number could refer to different blocks on different forks.
Hash(Bytes)
Identifies a block by its hash.
The hash should be unique across multiple chains. Preferred method if the block is very recent.
Latest(Chain)
Latest stored block for the target chain
Returns the block with the highest block number on the target chain.